FixCommand class final

Inheritance
Mixed-in types

Constructors

FixCommand(CommandContextFactory commandContextFactory)

Properties

aliases List<String>
Alternate names for this command.
no setterinherited
argParser → ArgParser
The argument parser for this command.
no setterinherited
argResults → ArgResults?
The parsed argument results for this command.
no setterinherited
arguments List<Argument>
no setterinherited
category String
The command's category.
no setteroverride
description String
A description of this command, included in usage.
no setteroverride
globalResults → ArgResults?
The parsed global argument results.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
hidden bool
Whether or not this command should be hidden from help listings.
no setterinherited
invocation String
A single-line template for how to invoke this command (e.g. "pub get package").
no setterinherited
name String
The name of this command.
no setteroverride
parent → Command<int>?
The command's parent command, if this is a subcommand.
no setterinherited
runner → CommandRunner<int>?
The command runner for this command.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subcommands Map<String, Command<int>>
An unmodifiable view of all sublevel commands of this command.
no setterinherited
suggestionAliases List<String>
Alternate non-functional names for this command.
no setterinherited
summary String
A short description of this command, included in parent's CommandRunner.usage.
no setterinherited
takesArguments bool
Whether or not this command takes positional arguments in addition to options.
no setterinherited
usage String
Generates a string displaying usage information for this command.
no setterinherited
usageFooter String?
An optional footer for usage.
no setterinherited
usageWithoutDescription String
no setterinherited

Methods

addArgument(String name, {String? help}) → void
inherited
addSubcommand(Command<int> command) → void
Adds Command as a subcommand of this.
inherited
argument(String name) String?
inherited
execute(CommandContext context) Future<int>
override
getCommandUsage(Map<String, Command> commands, {bool isSubcommand = false, int? lineLength}) String
Returns a string representation of commands fit for use in a usage string.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
padRight(String source, int length) String
Pads source to length by adding spaces at the end.
inherited
printUsage() → void
Prints the usage information for this command.
inherited
run() Future<int>
Runs this command.
inherited
toString() String
A string representation of this object.
inherited
usageException(String message) → Never
Throws a UsageException with message.
inherited
wrapText(String text, {int? length, int? hangingIndent}) String
Wraps a block of text into lines no longer than length.
inherited
wrapTextAsLines(String text, {int start = 0, int? length}) List<String>
Wraps a block of text into lines no longer than length, starting at the start column, and returns the result as a list of strings.
inherited
wrapUsage(String text, {int? hangingIndent}) String
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

migrationIdentityArg → const String