FixAction class final
Constructors
Properties
- console → Console?
-
final
- env → EnvConfig
-
final
- handler → FixingHandler?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- migrationIdentity → String
-
final
- migrationsPath → String
-
final
- password → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
execute(
) → Future< int> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited